==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/handlers/admissionregistration/v1beta1/MutatingWebhookConfigurationHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.admissionregistration.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.admissionregistration.v1beta1.MutatingWebhookConfigurationOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfiguration;
import io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfigurationBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class MutatingWebhookConfigurationHandler implements ResourceHandler<MutatingWebhookConfiguration, MutatingWebhookConfigurationBuilder> {

  @Override
  public String getKind() {
    return MutatingWebhookConfiguration.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "admissionregistration.k8s.io/v1beta1";
      }

  @Override
  public MutatingWebhookConfiguration create(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public MutatingWebhookConfiguration replace(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public MutatingWebhookConfiguration reload(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public MutatingWebhookConfigurationBuilder edit(MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, String resourceVersion, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, ListOptions options, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public MutatingWebhookConfiguration waitUntilReady(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public MutatingWebhookConfiguration waitUntilCondition(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, Predicate<MutatingWebhookConfiguration> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.3.0-sources.jar: io/fabric8/kubernetes/client/handlers/admissionregistration/v1beta1/MutatingWebhookConfigurationHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.admissionregistration.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.admissionregistration.v1beta1.MutatingWebhookConfigurationOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfiguration;
import io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.MutatingWebhookConfigurationBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class MutatingWebhookConfigurationHandler implements ResourceHandler<MutatingWebhookConfiguration, MutatingWebhookConfigurationBuilder> {

  @Override
  public String getKind() {
    return MutatingWebhookConfiguration.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "admissionregistration.k8s.io/v1beta1";
      }

  @Override
  public MutatingWebhookConfiguration create(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, boolean dryRun) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public MutatingWebhookConfiguration replace(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, boolean dryRun) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public MutatingWebhookConfiguration reload(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public MutatingWebhookConfigurationBuilder edit(MutatingWebhookConfiguration item) {
    return new MutatingWebhookConfigurationBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, MutatingWebhookConfiguration item, boolean dryRun) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, String resourceVersion, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, ListOptions options, Watcher<MutatingWebhookConfiguration> watcher) {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public MutatingWebhookConfiguration waitUntilReady(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public MutatingWebhookConfiguration waitUntilCondition(OkHttpClient client, Config config, String namespace, MutatingWebhookConfiguration item, Predicate<MutatingWebhookConfiguration> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new MutatingWebhookConfigurationOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
